@@ -9,10 +9,11 @@
  * open62541 Version
  * ----------------- */
 #define UA_OPEN62541_VER_MAJOR 1
-#define UA_OPEN62541_VER_MINOR 2
-#define UA_OPEN62541_VER_PATCH 3
+#define UA_OPEN62541_VER_MINOR 3
+#define UA_OPEN62541_VER_PATCH 0
 #define UA_OPEN62541_VER_LABEL "" /* Release candidate label, etc. */
-#define UA_OPEN62541_VER_COMMIT "v1.2.3"
+#define UA_OPEN62541_VER_COMMIT "v1.3"
+#define UA_OPEN62541_VERSION "v1.3.0"
 
 /**
  * Feature Options
@@ -27,24 +28,29 @@
 #define UA_ENABLE_NODEMANAGEMENT
 #define UA_ENABLE_SUBSCRIPTIONS
 /* #undef UA_ENABLE_PUBSUB */
+/* #undef UA_ENABLE_PUBSUB_ENCRYPTION */
 /* #undef UA_ENABLE_PUBSUB_FILE_CONFIG */
 /* #undef UA_ENABLE_PUBSUB_ETH_UADP */
-/* #undef UA_ENABLE_PUBSUB_ETH_UADP_ETF */
-/* #undef UA_ENABLE_PUBSUB_ETH_UADP_XDP */
 /* #undef UA_ENABLE_PUBSUB_DELTAFRAMES */
 /* #undef UA_ENABLE_PUBSUB_INFORMATIONMODEL */
 /* #undef UA_ENABLE_PUBSUB_INFORMATIONMODEL_METHODS */
 #define UA_ENABLE_DA
-#define UA_ENABLE_ENCRYPTION
+/* #undef UA_ENABLE_DIAGNOSTICS */
 #define UA_ENABLE_HISTORIZING
 #define UA_ENABLE_PARSING
-/* #undef UA_ENABLE_MICRO_EMB_DEV_PROFILE */
 /* #undef UA_ENABLE_EXPERIMENTAL_HISTORIZING */
-/* #undef UA_ENABLE_SUBSCRIPTIONS_EVENTS */
+#define UA_ENABLE_SUBSCRIPTIONS_EVENTS
 /* #undef UA_ENABLE_JSON_ENCODING */
 /* #undef UA_ENABLE_PUBSUB_MQTT */
+/* #undef UA_ENABLE_MQTT_TLS */
+/* #undef UA_ENABLE_MQTT_TLS_OPENSSL */
 /* #undef UA_ENABLE_ENCRYPTION_MBEDTLS */
-#define UA_ENABLE_ENCRYPTION_OPENSSL
+/* #undef UA_ENABLE_TPM2_SECURITY */
+/* #undef UA_ENABLE_ENCRYPTION_OPENSSL */
+/* #undef UA_ENABLE_ENCRYPTION_LIBRESSL */
+#if defined(UA_ENABLE_ENCRYPTION_MBEDTLS) || defined(UA_ENABLE_ENCRYPTION_OPENSSL) || defined(UA_ENABLE_ENCRYPTION_LIBRESSL)
+#define UA_ENABLE_ENCRYPTION
+#endif
 /* #undef UA_ENABLE_SUBSCRIPTIONS_ALARMS_CONDITIONS */
 
 /* Multithreading */
@@ -68,13 +74,14 @@
 #define UA_GENERATED_NAMESPACE_ZERO
 /* #undef UA_GENERATED_NAMESPACE_ZERO_FULL */
 /* #undef UA_ENABLE_PUBSUB_MONITORING */
+/* #undef UA_ENABLE_PUBSUB_BUFMALLOC */
 
 /* #undef UA_PACK_DEBIAN */
 
 /* Options for Debugging */
 /* #undef UA_DEBUG */
 /* #undef UA_DEBUG_DUMP_PKGS */
-
+/* #undef UA_DEBUG_FILE_LINE_INFO */
 /**
  * Function Export
  * ---------------
@@ -108,6 +115,25 @@
 # endif
 #endif
 
+/**
+ * POSIX Feature Flags
+ * -------------------
+ * These feature flags have to be set before including the first POSIX
+ * header. */
+#ifdef UA_ARCHITECTURE_POSIX
+# if !defined(_XOPEN_SOURCE)
+#  define _XOPEN_SOURCE 600
+# endif
+# ifndef _DEFAULT_SOURCE
+#  define _DEFAULT_SOURCE
+# endif
+/* On older systems we need to define _BSD_SOURCE.
+ * _DEFAULT_SOURCE is an alias for that. */
+# ifndef _BSD_SOURCE
+#  define _BSD_SOURCE
+# endif
+#endif
+
 // specific architectures can undef this
 #define UA_HAS_GETIFADDR
 
